@@ -10,14 +10,28 @@
  */
 
 /*
- *   $Header: /storage/repository/attachment_tnef/functions.php,v 1.1.1.1 2003/07/02 09:12:46 bernd Exp $
+ *   $Header: /storage/repository/attachment_tnef/functions.php,v 1.4 2003/09/11 11:36:45 bernd Exp $
  *
  *   $Log: functions.php,v $
+ *   Revision 1.4  2003/09/11 11:36:45  bernd
+ *   Preparations for beta release.
+ *
+ *   Revision 1.2  2003/07/31 15:24:25  bernd
+ *   Complete rework of tnef decoder
+ *
  *   Revision 1.1.1.1  2003/07/02 09:12:46  bernd
  *   initial import into CVS
  *
  */
 
+$ext_mime_array = array( '.gif' => 'image/gif', '.jpg' => 'image/jpg', '.png' => 'image/png' );
+
+function ext_to_mime($extension) {
+  global $ext_mime_array;
+
+  return  $ext_mime_array[$extension];
+}
+
 /*
  *  Generate browser-specific headers to initiate file download.
  *
@@ -31,7 +45,7 @@
  *
  */
 
-function DumpHeaders($type0, $type1, $filename, $length, $force)
+function DumpHeaders($type, $filename, $length, $force)
 {
    global $HTTP_USER_AGENT;
 
@@ -49,7 +63,7 @@ function DumpHeaders($type0, $type1, $filename, $length, $force)
    {
       // Try to show in browser window
       header("Content-Disposition: inline; filename=\"$filename\"");
-      header("Content-Type: $type0/$type1; name=\"$filename\"");
+      header("Content-Type: $type; name=\"$filename\"");
       header("Content-Length: $length");
    }
    else
@@ -104,4 +118,64 @@ function attachment_tnef_preview_do()
   // does not have to click on "view" to directly access its contents
 }
 
+function tnef_getx($size, &$buf)
+{
+   $value = null;
+   $len = strlen($buf);
+   if ($len >= $size)
+   {
+      $value = substr($buf, 0, $size);
+      $buf = substr_replace($buf, '', 0, $size);
+   } else {
+     substr_replace($buf, '', 0, $len);
+   }
+   return $value;
+}
+
+function tnef_geti8(&$buf)
+{
+   $value = null;
+   $len = strlen($buf);
+   if ($len >= 1)
+   {
+      $value = ord($buf{0});
+      $buf = substr_replace($buf, '', 0, 1);
+   } else {
+     substr_replace($buf, '', 0, $len);
+   }
+   return $value;
+}
+
+function tnef_geti16(&$buf)
+{
+   $value = null;
+   $len = strlen($buf);
+   if ($len >= 2)
+   {
+      $value = ord($buf{0}) +
+               (ord($buf{1}) << 8);
+      $buf = substr_replace($buf, '', 0, 2);
+   } else {
+     substr_replace($buf, '', 0, $len);
+   }
+   return $value;
+}
+
+function tnef_geti32(&$buf)
+{
+   $value = null;
+   $len = strlen($buf);
+   if ($len >= 4)
+   {
+      $value = ord($buf{0}) +
+               (ord($buf{1}) << 8) +
+               (ord($buf{2}) << 16) +
+               (ord($buf{3}) << 24);
+      $buf = substr_replace($buf, '', 0, 4);
+   } else {
+     substr_replace($buf, '', 0, $len);
+   }
+   return $value;
+}
+
 ?>
